@@ -1,13 +1,14 @@
 <?php
 
 // Start of Core v.5.3.6-13ubuntu3.2
+use JetBrains\PhpStorm\ExpectedValues;
+use JetBrains\PhpStorm\Pure;
 
 /**
  * Created by typecasting to object.
  * @link https://php.net/manual/en/reserved.classes.php
  */
-class stdClass {
-}
+class stdClass {}
 
 /**
  * @link https://wiki.php.net/rfc/iterable
@@ -21,15 +22,14 @@ interface iterable {}
  *
  * @link https://php.net/manual/en/class.traversable.php
  */
-interface Traversable extends iterable {
-}
+interface Traversable extends iterable {}
 
 /**
  * Interface to create an external Iterator.
  * @link https://php.net/manual/en/class.iteratoraggregate.php
  */
-interface IteratorAggregate extends Traversable {
-
+interface IteratorAggregate extends Traversable
+{
     /**
      * Retrieve an external iterator
      * @link https://php.net/manual/en/iteratoraggregate.getiterator.php
@@ -45,8 +45,8 @@ interface IteratorAggregate extends Traversable {
  * themselves internally.
  * @link https://php.net/manual/en/class.iterator.php
  */
-interface Iterator extends Traversable {
-
+interface Iterator extends Traversable
+{
     /**
      * Return the current element
      * @link https://php.net/manual/en/iterator.current.php
@@ -88,8 +88,8 @@ interface Iterator extends Traversable {
  * Interface to provide accessing objects as arrays.
  * @link https://php.net/manual/en/class.arrayaccess.php
  */
-interface ArrayAccess {
-
+interface ArrayAccess
+{
     /**
      * Whether a offset exists
      * @link https://php.net/manual/en/arrayaccess.offsetexists.php
@@ -141,27 +141,25 @@ interface ArrayAccess {
  * Interface for customized serializing.
  * @link https://php.net/manual/en/class.serializable.php
  */
-interface Serializable {
-
+interface Serializable
+{
     /**
-     * String representation of object
+     * String representation of object.
      * @link https://php.net/manual/en/serializable.serialize.php
-     * @return string the string representation of the object or null
+     * @return string|null The string representation of the object or null
+     * @throws Exception Returning other type than string or null
      */
     public function serialize();
 
     /**
-     * Constructs the object
+     * Constructs the object.
      * @link https://php.net/manual/en/serializable.unserialize.php
-     * @param string $serialized <p>
-     * The string representation of the object.
-     * </p>
+     * @param string $data The string representation of the object.
      * @return void
      */
-    public function unserialize($serialized);
+    public function unserialize($data);
 }
 
-
 /**
  * Throwable is the base interface for any object that can be thrown via a throw statement in PHP 7,
  * including Error and Exception.
@@ -170,7 +168,6 @@ interface Serializable {
  */
 interface Throwable extends Stringable
 {
-
     /**
      * Gets the message
      * @link https://php.net/manual/en/throwable.getmessage.php
@@ -230,7 +227,7 @@ interface Throwable extends Stringable
     /**
      * Returns the previous Throwable
      * @link https://php.net/manual/en/throwable.getprevious.php
-     * @return Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
+     * @return null|Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
      * @since 7.0
      */
     public function getPrevious();
@@ -248,7 +245,8 @@ interface Throwable extends Stringable
  * all Exceptions.
  * @link https://php.net/manual/en/class.exception.php
  */
-class Exception implements Throwable {
+class Exception implements Throwable
+{
     /** The error message */
     protected $message;
     /** The error code */
@@ -258,30 +256,31 @@ class Exception implements Throwable {
     /** The line where the error happened */
     protected $line;
 
-
     /**
      * Clone the exception
      * Tries to clone the Exception, which results in Fatal error.
      * @link https://php.net/manual/en/exception.clone.php
      * @return void
      */
-    final private function __clone() { }
+    final private function __clone() {}
 
     /**
      * Construct the exception. Note: The message is NOT binary safe.
      * @link https://php.net/manual/en/exception.construct.php
      * @param string $message [optional] The Exception message to throw.
      * @param int $code [optional] The Exception code.
-     * @param Throwable $previous [optional] The previous throwable used for the exception chaining.
+     * @param null|Throwable $previous [optional] The previous throwable used for the exception chaining.
      */
-    public function __construct($message = "", $code = 0, Throwable $previous = null) { }
+    #[Pure]
+    public function __construct($message = "", $code = 0, Throwable $previous = null) {}
 
     /**
      * Gets the Exception message
      * @link https://php.net/manual/en/exception.getmessage.php
      * @return string the Exception message as a string.
      */
-    final public function getMessage() { }
+    #[Pure]
+    final public function getMessage() {}
 
     /**
      * Gets the Exception code
@@ -291,52 +290,58 @@ class Exception implements Throwable {
      * <b>Exception</b> descendants (for example as
      * string in <b>PDOException</b>).
      */
-    final public function getCode() { }
+    #[Pure]
+    final public function getCode() {}
 
     /**
      * Gets the file in which the exception occurred
      * @link https://php.net/manual/en/exception.getfile.php
      * @return string the filename in which the exception was created.
      */
-    final public function getFile() { }
+    #[Pure]
+    final public function getFile() {}
 
     /**
      * Gets the line in which the exception occurred
      * @link https://php.net/manual/en/exception.getline.php
      * @return int the line number where the exception was created.
      */
-    final public function getLine() { }
+    #[Pure]
+    final public function getLine() {}
 
     /**
      * Gets the stack trace
      * @link https://php.net/manual/en/exception.gettrace.php
      * @return array the Exception stack trace as an array.
      */
-    final public function getTrace() { }
+    #[Pure]
+    final public function getTrace() {}
 
     /**
      * Returns previous Exception
      * @link https://php.net/manual/en/exception.getprevious.php
-     * @return Exception the previous <b>Exception</b> if available
+     * @return null|Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
      * or null otherwise.
      */
-    final public function getPrevious() { }
+    #[Pure]
+    final public function getPrevious() {}
 
     /**
      * Gets the stack trace as a string
      * @link https://php.net/manual/en/exception.gettraceasstring.php
      * @return string the Exception stack trace as a string.
      */
-    final public function getTraceAsString() { }
+    #[Pure]
+    final public function getTraceAsString() {}
 
     /**
      * String representation of the exception
      * @link https://php.net/manual/en/exception.tostring.php
      * @return string the string representation of the exception.
      */
-    public function __toString() { }
+    public function __toString() {}
 
-    public function __wakeup() { }
+    public function __wakeup() {}
 }
 
 /**
@@ -344,8 +349,8 @@ class Exception implements Throwable {
  * @link https://php.net/manual/en/class.error.php
  * @since 7.0
  */
-class Error implements Throwable {
-
+class Error implements Throwable
+{
     /** The error message */
     protected $message;
     /** The error code */
@@ -360,11 +365,10 @@ class Error implements Throwable {
      * @link https://php.net/manual/en/error.construct.php
      * @param string $message [optional] The Error message to throw.
      * @param int $code [optional] The Error code.
-     * @param Throwable $previous [optional] The previous throwable used for the exception chaining.
+     * @param null|Throwable $previous [optional] The previous throwable used for the exception chaining.
      */
-    public function __construct($message = "", $code = 0, Throwable $previous = null)
-    {
-    }
+    #[Pure]
+    public function __construct($message = "", $code = 0, Throwable $previous = null) {}
 
     /***
      * Gets the message
@@ -372,9 +376,7 @@ class Error implements Throwable {
      * @return string
      * @since 7.0
      */
-    public final function getMessage()
-    {
-    }
+    final public function getMessage() {}
 
     /**
      * Gets the exception code
@@ -387,8 +389,7 @@ class Error implements Throwable {
      * </p>
      * @since 7.0
      */
-    public final function getCode(){}
-
+    final public function getCode() {}
 
     /**
      * Gets the file in which the exception occurred
@@ -396,8 +397,7 @@ class Error implements Throwable {
      * @return string Returns the name of the file from which the object was thrown.
      * @since 7.0
      */
-    public final function getFile(){}
-
+    final public function getFile() {}
 
     /**
      * Gets the line on which the object was instantiated
@@ -405,8 +405,7 @@ class Error implements Throwable {
      * @return int Returns the line number where the thrown object was instantiated.
      * @since 7.0
      */
-    public final function getLine(){}
-
+    final public function getLine() {}
 
     /**
      * Gets the stack trace
@@ -417,7 +416,7 @@ class Error implements Throwable {
      * </p>
      * @since 7.0
      */
-    public final function getTrace(){}
+    final public function getTrace() {}
 
     /**
      * Gets the stack trace as a string
@@ -425,22 +424,23 @@ class Error implements Throwable {
      * @return string Returns the stack trace as a string.
      * @since 7.0
      */
-    public final function getTraceAsString(){}
+    final public function getTraceAsString() {}
 
     /**
      * Returns the previous Throwable
      * @link https://php.net/manual/en/throwable.getprevious.php
-     * @return Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
+     * @return null|Throwable Returns the previous {@see Throwable} if available, or <b>NULL</b> otherwise.
      * @since 7.0
      */
-    public final function getPrevious(){}
+    final public function getPrevious() {}
+
     /**
      * Gets a string representation of the thrown object
      * @link https://php.net/manual/en/throwable.tostring.php
      * @return string <p>Returns the string representation of the thrown object.</p>
      * @since 7.0
      */
-    public function __toString(){}
+    public function __toString() {}
 
     /**
      * Clone the error
@@ -448,9 +448,9 @@ class Error implements Throwable {
      * @return void
      * @link https://php.net/manual/en/error.clone.php
      */
-    private final function __clone(){}
+    final private function __clone() {}
 
-    public function __wakeup(){}
+    public function __wakeup() {}
 }
 
 class ValueError extends Error {}
@@ -463,18 +463,14 @@ class ValueError extends Error {}
  * @link https://php.net/manual/en/class.typeerror.php
  * @since 7.0
  */
-class TypeError extends Error {
-
-}
+class TypeError extends Error {}
 
 /**
  * ParseError is thrown when an error occurs while parsing PHP code, such as when {@see eval()} is called.
  * @link https://php.net/manual/en/class.parseerror.php
  * @since 7.0
  */
-class ParseError extends CompileError {
-
-}
+class ParseError extends CompileError {}
 
 /**
  * ArgumentCountError is thrown when too few arguments are passed to a user
@@ -492,27 +488,21 @@ class ArgumentCountError extends TypeError {}
  * @link https://php.net/manual/en/class.arithmeticerror.php
  * @since 7.0
  */
-class ArithmeticError extends Error {
-
-}
+class ArithmeticError extends Error {}
 
 /**
  * Class CompileError
  * @link https://secure.php.net/manual/en/class.compileerror.php
  * @since 7.3
  */
-class CompileError extends Error {
-
-}
+class CompileError extends Error {}
 
 /**
  * DivisionByZeroError is thrown when an attempt is made to divide a number by zero.
  * @link https://php.net/manual/en/class.divisionbyzeroerror.php
  * @since 7.0
  */
-class DivisionByZeroError extends ArithmeticError {
-
-}
+class DivisionByZeroError extends ArithmeticError {}
 
 /**
  * @since 8.0
@@ -523,11 +513,10 @@ class UnhandledMatchError extends Error {}
  * An Error Exception.
  * @link https://php.net/manual/en/class.errorexception.php
  */
-class ErrorException extends Exception {
-
+class ErrorException extends Exception
+{
     protected $severity;
 
-
     /**
      * Constructs the exception
      * @link https://php.net/manual/en/errorexception.construct.php
@@ -535,17 +524,18 @@ class ErrorException extends Exception {
      * @param int $code [optional] The Exception code.
      * @param int $severity [optional] The severity level of the exception.
      * @param string $filename [optional] The filename where the exception is thrown.
-     * @param int $lineno [optional] The line number where the exception is thrown.
+     * @param int $line [optional] The line number where the exception is thrown.
      * @param Exception $previous [optional] The previous exception used for the exception chaining.
      */
-    public function __construct($message = "", $code = 0, $severity = 1, $filename = __FILE__, $lineno = __LINE__, $previous = null) { }
+    #[\JetBrains\PhpStorm\Pure]
+    public function __construct($message = "", $code = 0, $severity = 1, $filename = __FILE__, $line = __LINE__, $previous = null) {}
 
     /**
      * Gets the exception severity
      * @link https://php.net/manual/en/errorexception.getseverity.php
      * @return int the severity level of the exception.
      */
-    final public function getSeverity() { }
+    final public function getSeverity() {}
 }
 
 /**
@@ -557,14 +547,14 @@ class ErrorException extends Exception {
  * This is for consistency with other classes that implement calling magic, as this method is not used for calling the function.
  * @link https://secure.php.net/manual/en/class.closure.php
  */
-final class Closure {
-
+final class Closure
+{
     /**
      * This method exists only to disallow instantiation of the Closure class.
      * Objects of this class are created in the fashion described on the anonymous functions page.
      * @link https://secure.php.net/manual/en/closure.construct.php
      */
-    private function __construct() { }
+    private function __construct() {}
 
     /**
      * This is for consistency with other classes that implement calling magic,
@@ -573,48 +563,48 @@ final class Closure {
      * @return mixed
      * @link https://secure.php.net/manual/en/class.closure.php
      */
-    public function __invoke(...$_) { }
+    public function __invoke(...$_) {}
 
     /**
      * Duplicates the closure with a new bound object and class scope
      * @link https://secure.php.net/manual/en/closure.bindto.php
-     * @param object|null $newthis The object to which the given anonymous function should be bound, or NULL for the closure to be unbound.
-     * @param mixed $newscope The class scope to which associate the closure is to be associated, or 'static' to keep the current one.
+     * @param object|null $newThis The object to which the given anonymous function should be bound, or NULL for the closure to be unbound.
+     * @param mixed $newScope The class scope to which associate the closure is to be associated, or 'static' to keep the current one.
      * If an object is given, the type of the object will be used instead.
      * This determines the visibility of protected and private methods of the bound object.
      * @return Closure|false Returns the newly created Closure object or FALSE on failure
      */
-    function bindTo($newthis, $newscope = 'static') { }
+    public function bindTo(?object $newThis, object|string|null $newScope = 'static') {}
 
     /**
      * This method is a static version of Closure::bindTo().
      * See the documentation of that method for more information.
      * @link https://secure.php.net/manual/en/closure.bind.php
      * @param Closure $closure The anonymous functions to bind.
-     * @param object|null $newthis The object to which the given anonymous function should be bound, or NULL for the closure to be unbound.
-     * @param mixed $newscope The class scope to which associate the closure is to be associated, or 'static' to keep the current one.
+     * @param object|null $newThis The object to which the given anonymous function should be bound, or NULL for the closure to be unbound.
+     * @param mixed $newScope The class scope to which associate the closure is to be associated, or 'static' to keep the current one.
      * If an object is given, the type of the object will be used instead.
      * This determines the visibility of protected and private methods of the bound object.
      * @return Closure|false Returns the newly created Closure object or FALSE on failure
      */
-    static function bind(Closure $closure, $newthis, $newscope = 'static') { }
+    public static function bind(Closure $closure, ?object $newThis, object|string|null $newScope = 'static') {}
 
     /**
      * Temporarily binds the closure to newthis, and calls it with any given parameters.
      * @link https://php.net/manual/en/closure.call.php
      * @param object $newThis The object to bind the closure to for the duration of the call.
-     * @param mixed $parameters [optional] Zero or more parameters, which will be given as parameters to the closure.
+     * @param mixed $args [optional] Zero or more parameters, which will be given as parameters to the closure.
      * @return mixed
      * @since 7.0
      */
-    function call ($newthis, ...$parameters) {}
+    public function call(object $newThis, mixed ...$args) {}
 
     /**
-     * @param callable $callable
+     * @param callable $callback
      * @return Closure
      * @since 7.1
      */
-    public static function fromCallable (callable $callable) {}
+    public static function fromCallable(callable $callback) {}
 }
 
 /**
@@ -622,15 +612,15 @@ final class Closure {
  * <b>count</b> function.
  * @link https://php.net/manual/en/class.countable.php
  */
-interface Countable {
-
+interface Countable
+{
     /**
      * Count elements of an object
      * @link https://php.net/manual/en/countable.count.php
      * @return int The custom count as an integer.
-     * </p>
      * <p>
      * The return value is cast to an integer.
+     * </p>
      */
     public function count();
 }
@@ -641,7 +631,8 @@ interface Countable {
  * They are useful for implementing cache like structures.
  * @link https://www.php.net/manual/en/class.weakreference.php
  */
-class WeakReference {
+class WeakReference
+{
     /**
      * This method exists only to disallow instantiation of the WeakReference
      * class. Weak references are to be instantiated with the factory method
@@ -676,7 +667,8 @@ class WeakReference {
  *
  * @since 8.0
  */
-final class WeakMap implements \ArrayAccess, \Countable, \IteratorAggregate {
+final class WeakMap implements \ArrayAccess, \Countable, \IteratorAggregate
+{
     /**
      * Returns {@see true} if the value for the object is contained in
      * the {@see WeakMap} and {@see false} instead.
@@ -692,9 +684,7 @@ final class WeakMap implements \ArrayAccess, \Countable, \IteratorAggregate {
      * @param object $object Any object
      * @return mixed Value associated with the key object
      */
-    public function offsetGet($object)
-    {
-    }
+    public function offsetGet($object) {}
 
     /**
      * Sets a new value for an object.
@@ -703,9 +693,7 @@ final class WeakMap implements \ArrayAccess, \Countable, \IteratorAggregate {
      * @param mixed $value Any value
      * @return void
      */
-    public function offsetSet($object, $value)
-    {
-    }
+    public function offsetSet($object, mixed $value) {}
 
     /**
      * Force removes an object value from the {@see WeakMap} instance.
@@ -713,27 +701,21 @@ final class WeakMap implements \ArrayAccess, \Countable, \IteratorAggregate {
      * @param object $object Any object
      * @return void
      */
-    public function offsetUnset($object)
-    {
-    }
+    public function offsetUnset($object) {}
 
     /**
      * Returns an iterator in the "[object => mixed]" format.
      *
      * @return Traversable
      */
-    public function getIterator()
-    {
-    }
+    public function getIterator() {}
 
     /**
      * Returns the number of items in the {@see WeakMap} instance.
      *
      * @return int
      */
-    public function count()
-    {
-    }
+    public function count() {}
 }
 
 /**
@@ -742,7 +724,8 @@ final class WeakMap implements \ArrayAccess, \Countable, \IteratorAggregate {
  *
  * @since 8.0
  */
-interface Stringable {
+interface Stringable
+{
     /**
      * Magic method {@see https://www.php.net/manual/en/language.oop5.magic.php}
      * called during serialization to string.
@@ -757,56 +740,55 @@ interface Stringable {
  * @since 8.0
  */
 #[Attribute(Attribute::TARGET_CLASS)]
-final class Attribute {
+final class Attribute
+{
     public int $flags;
     /**
      * Marks that attribute declaration is allowed only in classes.
      */
-    const TARGET_CLASS = 1;
+    public const TARGET_CLASS = 1;
 
     /**
      * Marks that attribute declaration is allowed only in functions.
      */
-    const TARGET_FUNCTION = 1 << 1;
+    public const TARGET_FUNCTION = 2;
 
     /**
      * Marks that attribute declaration is allowed only in class methods.
      */
-    const TARGET_METHOD = 1 << 2;
+    public const TARGET_METHOD = 4;
 
     /**
      * Marks that attribute declaration is allowed only in class properties.
      */
-    const TARGET_PROPERTY = 1 << 3;
+    public const TARGET_PROPERTY = 8;
 
     /**
      * Marks that attribute declaration is allowed only in class constants.
      */
-    const TARGET_CLASS_CONSTANT = 1 << 4;
+    public const TARGET_CLASS_CONSTANT = 16;
 
     /**
      * Marks that attribute declaration is allowed only in function or method parameters.
      */
-    const TARGET_PARAMETER = 1 << 5;
+    public const TARGET_PARAMETER = 32;
 
     /**
      * Marks that attribute declaration is allowed anywhere.
      */
-    const TARGET_ALL = (1 << 6) - 1;
+    public const TARGET_ALL = 63;
 
     /**
      * Notes that an attribute declaration in the same place is
      * allowed multiple times.
      */
-    const IS_REPEATABLE = 1 << 10;
+    public const IS_REPEATABLE = 64;
 
     /**
      * @param int $flags A value in the form of a bitmask indicating the places
      * where attributes can be defined.
      */
-    public function __construct($flags = self::TARGET_ALL)
-    {
-    }
+    public function __construct(#[ExpectedValues(flagsFromClass: Attribute::class)] int $flags = self::TARGET_ALL) {}
 }
 
 /**
@@ -815,7 +797,8 @@ final class Attribute {
  *
  * @since 8.0
  */
-class PhpToken implements Stringable {
+class PhpToken implements Stringable
+{
     /**
      * One of the T_* constants, or an integer < 256 representing a
      * single-char token.
@@ -837,6 +820,21 @@ class PhpToken implements Stringable {
      */
     public int $pos;
 
+    /**
+     * @param int $id An integer identifier
+     * @param string $text Textual content
+     * @param int $line Strating line
+     * @param int $pos Straring position (line offset)
+     */
+    final public function __construct(int $id, string $text, int $line = -1, int $pos = -1) {}
+
+    /**
+     * Get the name of the token.
+     *
+     * @return string|null
+     */
+    public function getTokenName() {}
+
     /**
      * Same as {@see token_get_all()}, but returning array of {@see PhpToken}
      * or an instance of a child class.
@@ -845,28 +843,7 @@ class PhpToken implements Stringable {
      * @param int $flags
      * @return static[]
      */
-    public static function getAll($code, $flags = 0)
-    {
-    }
-
-    /**
-     * @param int $id An integer identifier
-     * @param string $text Textual content
-     * @param int $line Strating line
-     * @param int $pos Straring position (line offset)
-     */
-    final public function __construct($id, $text, $line = -1, $pos = -1)
-    {
-    }
-
-    /**
-     * Get the name of the token.
-     *
-     * @return string|null
-     */
-    public function getTokenName()
-    {
-    }
+    public static function tokenize(string $code, int $flags = 0) {}
 
     /**
      * Whether the token has the given ID, the given text, or has an ID/text
@@ -875,39 +852,34 @@ class PhpToken implements Stringable {
      * @param int|string|array $kind
      * @return bool
      */
-    public function is($kind)
-    {
-    }
+    public function is($kind) {}
 
     /**
      * Whether this token would be ignored by the PHP parser.
      *
      * @return bool
      */
-    public function isIgnorable()
-    {
-    }
+    public function isIgnorable() {}
 
     /**
      * {@inheritDoc}
      */
-    public function __toString()
-    {
-    }
+    public function __toString() {}
 }
 
 /**
  * @since 8.0
  */
-final class InternalIterator implements Iterator{
-    private function __construct(){}
-    public function current(){}
+final class InternalIterator implements Iterator
+{
+    private function __construct() {}
+    public function current() {}
 
-    public function next(){}
+    public function next() {}
 
-    public function key(){}
+    public function key() {}
 
-    public function valid(){}
+    public function valid() {}
 
-    public function rewind(){}
+    public function rewind() {}
 }
