@@ -1,18 +1,20 @@
 <?php
 
 // Start of gettext v.
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Pure;
 
 /**
  * Sets the default domain
  * @link https://php.net/manual/en/function.textdomain.php
- * @param string|null $text_domain <p>
+ * @param string|null $domain <p>
  * The new message domain, or <b>NULL</b> to get the current setting without
  * changing it
  * </p>
  * @return string If successful, this function returns the current message
  * domain, after possibly changing it.
  */
-function textdomain ($text_domain) {}
+function textdomain(?string $domain): string {}
 
 /**
  * Lookup a message in the current domain
@@ -23,7 +25,8 @@ function textdomain ($text_domain) {}
  * @return string a translated string if one is found in the
  * translation table, or the submitted message if not found.
  */
-function gettext ($message) {}
+#[Pure]
+function _(string $message): string {}
 
 /**
  * Lookup a message in the current domain
@@ -34,7 +37,8 @@ function gettext ($message) {}
  * @return string a translated string if one is found in the
  * translation table, or the submitted message if not found.
  */
-function _ ($message) {}
+#[Pure]
+function gettext(string $message): string {}
 
 /**
  * Override the current domain
@@ -47,7 +51,7 @@ function _ ($message) {}
  * </p>
  * @return string A string on success.
  */
-function dgettext ($domain, $message) {}
+function dgettext(string $domain, string $message): string {}
 
 /**
  * Overrides the domain for a single lookup
@@ -63,7 +67,7 @@ function dgettext ($domain, $message) {}
  * </p>
  * @return string A string on success.
  */
-function dcgettext ($domain, $message, $category) {}
+function dcgettext(string $domain, string $message, int $category): string {}
 
 /**
  * Sets the path for a domain
@@ -71,24 +75,25 @@ function dcgettext ($domain, $message, $category) {}
  * @param string $domain <p>
  * The domain
  * </p>
- * @param string $directory <p>
- * The directory path
+ * @param string|null $directory <p>
+ * The directory path. Since PHP 8.0.3 directory is nullable. If null is passed, the currently set directory is returned.
  * </p>
- * @return string The full pathname for the <i>domain</i> currently being set.
+ * @return string|false The full pathname for the <i>domain</i> currently being set.
  */
-function bindtextdomain ($domain, $directory) {}
+function bindtextdomain(string $domain, #[LanguageLevelTypeAware(['8.0' => '?string'], default: 'string')] $directory): string|false {}
 
 /**
  * Plural version of gettext
  * @link https://php.net/manual/en/function.ngettext.php
- * @param string $msgid1
- * @param string $msgid2
- * @param int $n
+ * @param string $singular
+ * @param string $plural
+ * @param int $count
  * @return string correct plural form of message identified by
  * <i>msgid1</i> and <i>msgid2</i>
  * for count <i>n</i>.
  */
-function ngettext ($msgid1, $msgid2, $n) {}
+#[Pure]
+function ngettext(string $singular, string $plural, int $count): string {}
 
 /**
  * Plural version of dgettext
@@ -96,12 +101,13 @@ function ngettext ($msgid1, $msgid2, $n) {}
  * @param string $domain <p>
  * The domain
  * </p>
- * @param string $msgid1
- * @param string $msgid2
- * @param int $n
+ * @param string $singular
+ * @param string $plural
+ * @param int $count
  * @return string A string on success.
  */
-function dngettext ($domain, $msgid1, $msgid2, $n) {}
+#[Pure]
+function dngettext(string $domain, string $singular, string $plural, int $count): string {}
 
 /**
  * Plural version of dcgettext
@@ -109,13 +115,14 @@ function dngettext ($domain, $msgid1, $msgid2, $n) {}
  * @param string $domain <p>
  * The domain
  * </p>
- * @param string $msgid1
- * @param string $msgid2
- * @param int $n
+ * @param string $singular
+ * @param string $plural
+ * @param int $count
  * @param int $category
  * @return string A string on success.
  */
-function dcngettext ($domain, $msgid1, $msgid2, $n, $category) {}
+#[Pure]
+function dcngettext(string $domain, string $singular, string $plural, int $count, int $category): string {}
 
 /**
  * Specify the character encoding in which the messages from the DOMAIN message catalog will be returned
@@ -123,12 +130,11 @@ function dcngettext ($domain, $msgid1, $msgid2, $n, $category) {}
  * @param string $domain <p>
  * The domain
  * </p>
- * @param string $codeset <p>
- * The code set
+ * @param string|null $codeset <p>
+ * The code set. Since 8.0.3 is nullable.  If null is passed, the currently set encoding is returned.
  * </p>
- * @return string A string on success.
+ * @return string|false A string on success.
  */
-function bind_textdomain_codeset ($domain, $codeset) {}
+function bind_textdomain_codeset(string $domain, #[LanguageLevelTypeAware(['8.0' => '?string'], default: 'string')] $codeset): string|false {}
 
 // End of gettext v.
-?>
