@@ -1,67 +1,72 @@
 <?php
 
 // Start of posix v.
+use JetBrains\PhpStorm\Pure;
 
 /**
  * Send a signal to a process
  * @link https://php.net/manual/en/function.posix-kill.php
- * @param int $pid <p>
+ * @param int $process_id <p>
  * The process identifier.
  * </p>
- * @param int $sig <p>
+ * @param int $signal <p>
  * One of the PCNTL signals constants.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_kill ($pid, $sig) {}
+function posix_kill(int $process_id, int $signal): bool {}
 
 /**
  * Return the current process identifier
  * @link https://php.net/manual/en/function.posix-getpid.php
  * @return int the identifier, as an integer.
  */
-function posix_getpid () {}
+#[Pure]
+function posix_getpid(): int {}
 
 /**
  * Return the parent process identifier
  * @link https://php.net/manual/en/function.posix-getppid.php
  * @return int the identifier, as an integer.
  */
-function posix_getppid () {}
+#[Pure]
+function posix_getppid(): int {}
 
 /**
  * Return the real user ID of the current process
  * @link https://php.net/manual/en/function.posix-getuid.php
  * @return int the user id, as an integer
  */
-function posix_getuid () {}
+#[Pure]
+function posix_getuid(): int {}
 
 /**
  * Set the UID of the current process
  * @link https://php.net/manual/en/function.posix-setuid.php
- * @param int $uid <p>
+ * @param int $user_id <p>
  * The user id.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_setuid ($uid) {}
+function posix_setuid(int $user_id): bool {}
 
 /**
  * Return the effective user ID of the current process
  * @link https://php.net/manual/en/function.posix-geteuid.php
  * @return int the user id, as an integer
  */
-function posix_geteuid () {}
+#[Pure]
+function posix_geteuid(): int {}
 
 /**
  * Set the effective UID of the current process
  * @link https://php.net/manual/en/function.posix-seteuid.php
- * @param int $uid <p>
+ * @param int $user_id <p>
  * The user id.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_seteuid ($uid) {}
+function posix_seteuid(int $user_id): bool {}
 
 /**
  * Set system resource limits
@@ -71,115 +76,122 @@ function posix_seteuid ($uid) {}
  * {@link https://php.net/manual/en/posix.constants.setrlimit.php resource limit constant}
  * corresponding to the limit that is being set.
  * </p>
- * @param int $softlimit The soft limit, in whatever unit the resource limit requires, or POSIX_RLIMIT_INFINITY.
- * @param int $hardlimit The hard limit, in whatever unit the resource limit requires, or POSIX_RLIMIT_INFINITY.
+ * @param int $soft_limit The soft limit, in whatever unit the resource limit requires, or POSIX_RLIMIT_INFINITY.
+ * @param int $hard_limit The hard limit, in whatever unit the resource limit requires, or POSIX_RLIMIT_INFINITY.
  * @return bool Returns TRUE on success or FALSE on failure.
  * @since 7.0
  */
-function posix_setrlimit ($resource, $softlimit, $hardlimit ) {}
+function posix_setrlimit(int $resource, int $soft_limit, int $hard_limit): bool {}
 /**
  * Return the real group ID of the current process
  * @link https://php.net/manual/en/function.posix-getgid.php
  * @return int the real group id, as an integer.
  */
-function posix_getgid () {}
+#[Pure]
+function posix_getgid(): int {}
 
 /**
  * Set the GID of the current process
  * @link https://php.net/manual/en/function.posix-setgid.php
- * @param int $gid <p>
+ * @param int $group_id <p>
  * The group id.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_setgid ($gid) {}
+function posix_setgid(int $group_id): bool {}
 
 /**
  * Return the effective group ID of the current process
  * @link https://php.net/manual/en/function.posix-getegid.php
  * @return int an integer of the effective group ID.
  */
-function posix_getegid () {}
+#[Pure]
+function posix_getegid(): int {}
 
 /**
  * Set the effective GID of the current process
  * @link https://php.net/manual/en/function.posix-setegid.php
- * @param int $gid <p>
+ * @param int $group_id <p>
  * The group id.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_setegid ($gid) {}
+function posix_setegid(int $group_id): bool {}
 
 /**
  * Return the group set of the current process
  * @link https://php.net/manual/en/function.posix-getgroups.php
- * @return array an array of integers containing the numeric group ids of the group
+ * @return array|false an array of integers containing the numeric group ids of the group
  * set of the current process.
  */
-function posix_getgroups () {}
+#[Pure]
+function posix_getgroups(): array|false {}
 
 /**
  * Return login name
  * @link https://php.net/manual/en/function.posix-getlogin.php
- * @return string the login name of the user, as a string.
+ * @return string|false the login name of the user, as a string.
  */
-function posix_getlogin () {}
+#[Pure]
+function posix_getlogin(): string|false {}
 
 /**
  * Return the current process group identifier
  * @link https://php.net/manual/en/function.posix-getpgrp.php
  * @return int the identifier, as an integer.
  */
-function posix_getpgrp () {}
+#[Pure]
+function posix_getpgrp(): int {}
 
 /**
  * Make the current process a session leader
  * @link https://php.net/manual/en/function.posix-setsid.php
  * @return int the session id, or -1 on errors.
  */
-function posix_setsid () {}
+function posix_setsid(): int {}
 
 /**
  * Set process group id for job control
  * @link https://php.net/manual/en/function.posix-setpgid.php
- * @param int $pid <p>
+ * @param int $process_id <p>
  * The process id.
  * </p>
- * @param int $pgid <p>
+ * @param int $process_group_id <p>
  * The process group id.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_setpgid ($pid, $pgid) {}
+function posix_setpgid(int $process_id, int $process_group_id): bool {}
 
 /**
  * Get process group id for job control
  * @link https://php.net/manual/en/function.posix-getpgid.php
- * @param int $pid <p>
+ * @param int $process_id <p>
  * The process id.
  * </p>
- * @return int the identifier, as an integer.
+ * @return int|false the identifier, as an integer.
  */
-function posix_getpgid ($pid) {}
+#[Pure]
+function posix_getpgid(int $process_id): int|false {}
 
 /**
  * Get the current sid of the process
  * @link https://php.net/manual/en/function.posix-getsid.php
- * @param int $pid <p>
+ * @param int $process_id <p>
  * The process identifier. If set to 0, the current process is
  * assumed. If an invalid <i>pid</i> is
  * specified, then <b>FALSE</b> is returned and an error is set which
  * can be checked with <b>posix_get_last_error</b>.
  * </p>
- * @return int the identifier, as an integer.
+ * @return int|false the identifier, as an integer.
  */
-function posix_getsid ($pid) {}
+#[Pure]
+function posix_getsid(int $process_id): int|false {}
 
 /**
  * Get system name
  * @link https://php.net/manual/en/function.posix-uname.php
- * @return array a hash of strings with information about the
+ * @return array|false a hash of strings with information about the
  * system. The indices of the hash are
  * sysname - operating system name (e.g. Linux)
  * nodename - system name (e.g. valiant)
@@ -194,12 +206,13 @@ function posix_getsid ($pid) {}
  * field is only available on GNU systems or when using the GNU
  * libc.
  */
-function posix_uname () {}
+#[Pure]
+function posix_uname(): array|false {}
 
 /**
  * Get process times
  * @link https://php.net/manual/en/function.posix-times.php
- * @return array a hash of strings with information about the current
+ * @return array|false a hash of strings with information about the current
  * process CPU usage. The indices of the hash are:
  * ticks - the number of clock ticks that have elapsed since
  * reboot.
@@ -208,7 +221,8 @@ function posix_uname () {}
  * cutime - user time used by current process and children.
  * cstime - system time used by current process and children.
  */
-function posix_times () {}
+#[Pure]
+function posix_times(): array|false {}
 
 /**
  * Get path name of controlling terminal
@@ -217,23 +231,25 @@ function posix_times () {}
  * the current controlling terminal. Otherwise <b>FALSE</b> is returned and errno
  * is set, which can be checked with <b>posix_get_last_error</b>.
  */
-function posix_ctermid () {}
+#[Pure]
+function posix_ctermid(): string|false {}
 
 /**
  * Determine terminal device name
  * @link https://php.net/manual/en/function.posix-ttyname.php
- * @param int $fd <p>
+ * @param int $file_descriptor <p>
  * The file descriptor.
  * </p>
  * @return string|false On success, returns a string of the absolute path of the
  * <i>fd</i>. On failure, returns <b>FALSE</b>
  */
-function posix_ttyname ($fd) {}
+#[Pure]
+function posix_ttyname($file_descriptor): string|false {}
 
 /**
  * Determine if a file descriptor is an interactive terminal
  * @link https://php.net/manual/en/function.posix-isatty.php
- * @param mixed $fd <p>
+ * @param mixed $file_descriptor <p>
  * The file descriptor, which is expected to be either a file resource or an integer.
  * An integer will be assumed to be a file descriptor that can be passed
  * directly to the underlying system call.<br />
@@ -242,41 +258,43 @@ function posix_ttyname ($fd) {}
  * @return bool <b>TRUE</b> if <i>fd</i> is an open descriptor connected
  * to a terminal and <b>FALSE</b> otherwise.
  */
-function posix_isatty ($fd) {}
+#[Pure]
+function posix_isatty($file_descriptor): bool {}
 
 /**
  * Pathname of current directory
  * @link https://php.net/manual/en/function.posix-getcwd.php
- * @return string a string of the absolute pathname on success.
+ * @return string|false a string of the absolute pathname on success.
  * On error, returns <b>FALSE</b> and sets errno which can be checked with
  * <b>posix_get_last_error</b>.
  */
-function posix_getcwd () {}
+#[Pure]
+function posix_getcwd(): string|false {}
 
 /**
  * Create a fifo special file (a named pipe)
  * @link https://php.net/manual/en/function.posix-mkfifo.php
- * @param string $pathname <p>
+ * @param string $filename <p>
  * Path to the FIFO file.
  * </p>
- * @param int $mode <p>
+ * @param int $permissions <p>
  * The second parameter <i>mode</i> has to be given in
  * octal notation (e.g. 0644). The permission of the newly created
  * FIFO also depends on the setting of the current
  * <b>umask</b>. The permissions of the created file are
- * (mode &#38;#38; ~umask).
+ * (mode & ~umask).
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_mkfifo ($pathname, $mode) {}
+function posix_mkfifo(string $filename, int $permissions): bool {}
 
 /**
  * Create a special or ordinary file (POSIX.1)
  * @link https://php.net/manual/en/function.posix-mknod.php
- * @param string $pathname <p>
+ * @param string $filename <p>
  * The file to create
  * </p>
- * @param int $mode <p>
+ * @param int $flags <p>
  * This parameter is constructed by a bitwise OR between file type (one of
  * the following constants: <b>POSIX_S_IFREG</b>,
  * <b>POSIX_S_IFCHR</b>, <b>POSIX_S_IFBLK</b>,
@@ -292,15 +310,15 @@ function posix_mkfifo ($pathname, $mode) {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_mknod ($pathname, $mode, $major = 0, $minor = 0) {}
+function posix_mknod(string $filename, int $flags, int $major = 0, int $minor = 0): bool {}
 
 /**
  * Determine accessibility of a file
  * @link https://php.net/manual/en/function.posix-access.php
- * @param string $file <p>
+ * @param string $filename <p>
  * The name of the file to be tested.
  * </p>
- * @param int $mode [optional] <p>
+ * @param int $flags [optional] <p>
  * A mask consisting of one or more of <b>POSIX_F_OK</b>,
  * <b>POSIX_R_OK</b>, <b>POSIX_W_OK</b> and
  * <b>POSIX_X_OK</b>.
@@ -314,13 +332,13 @@ function posix_mknod ($pathname, $mode, $major = 0, $minor = 0) {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_access ($file, $mode = POSIX_F_OK) {}
+function posix_access(string $filename, int $flags = POSIX_F_OK): bool {}
 
 /**
  * Return info about a group by name
  * @link https://php.net/manual/en/function.posix-getgrnam.php
  * @param string $name <p>The name of the group</p>
- * @return array The array elements returned are:
+ * @return array|false The array elements returned are:
  * <table>
  * The group information array
  * <tr valign="top">
@@ -360,15 +378,16 @@ function posix_access ($file, $mode = POSIX_F_OK) {}
  * </tr>
  * </table>
  */
-function posix_getgrnam ($name) {}
+#[Pure]
+function posix_getgrnam(string $name): array|false {}
 
 /**
  * Return info about a group by group id
  * @link https://php.net/manual/en/function.posix-getgrgid.php
- * @param int $gid <p>
+ * @param int $group_id <p>
  * The group id.
  * </p>
- * @return array The array elements returned are:
+ * @return array|false The array elements returned are:
  * <table>
  * The group information array
  * <tr valign="top">
@@ -408,7 +427,8 @@ function posix_getgrnam ($name) {}
  * </tr>
  * </table>
  */
-function posix_getgrgid ($gid) {}
+#[Pure]
+function posix_getgrgid(int $group_id): array|false {}
 
 /**
  * Return info about a user by username
@@ -416,7 +436,7 @@ function posix_getgrgid ($gid) {}
  * @param string $username <p>
  * An alphanumeric username.
  * </p>
- * @return array On success an array with the following elements is returned, else
+ * @return array|false On success an array with the following elements is returned, else
  * <b>FALSE</b> is returned:
  * <table>
  * The user information array
@@ -484,15 +504,16 @@ function posix_getgrgid ($gid) {}
  * </tr>
  * </table>
  */
-function posix_getpwnam ($username) {}
+#[Pure]
+function posix_getpwnam(string $username): array|false {}
 
 /**
  * Return info about a user by user id
  * @link https://php.net/manual/en/function.posix-getpwuid.php
- * @param int $uid <p>
+ * @param int $user_id <p>
  * The user identifier.
  * </p>
- * @return array an associative array with the following elements:
+ * @return array|false an associative array with the following elements:
  * <table>
  * The user information array
  * <tr valign="top">
@@ -559,12 +580,13 @@ function posix_getpwnam ($username) {}
  * </tr>
  * </table>
  */
-function posix_getpwuid ($uid) {}
+#[Pure]
+function posix_getpwuid(int $user_id): array|false {}
 
 /**
  * Return info about system resource limits
  * @link https://php.net/manual/en/function.posix-getrlimit.php
- * @return array an associative array of elements for each
+ * @return array|false an associative array of elements for each
  * limit that is defined. Each limit has a soft and a hard limit.
  * <table>
  * List of possible limits returned
@@ -643,7 +665,8 @@ function posix_getpwuid ($uid) {}
  * </tr>
  * </table>
  */
-function posix_getrlimit () {}
+#[Pure]
+function posix_getrlimit(): array|false {}
 
 /**
  * Retrieve the error number set by the last posix function that failed
@@ -651,104 +674,107 @@ function posix_getrlimit () {}
  * @return int the errno (error number) set by the last posix function that
  * failed. If no errors exist, 0 is returned.
  */
-function posix_get_last_error () {}
+#[Pure]
+function posix_get_last_error(): int {}
 
 /**
  * Alias of <b>posix_get_last_error</b>
  * @link https://php.net/manual/en/function.posix-errno.php
  */
-function posix_errno () {}
+#[Pure]
+function posix_errno(): int {}
 
 /**
  * Retrieve the system error message associated with the given errno
  * @link https://php.net/manual/en/function.posix-strerror.php
- * @param int $errno <p>
+ * @param int $error_code <p>
  * A POSIX error number, returned by
  * <b>posix_get_last_error</b>. If set to 0, then the
  * string "Success" is returned.
  * </p>
  * @return string the error message, as a string.
  */
-function posix_strerror ($errno) {}
+#[Pure]
+function posix_strerror(int $error_code): string {}
 
 /**
  * Calculate the group access list
  * @link https://php.net/manual/en/function.posix-initgroups.php
- * @param string $name <p>
+ * @param string $username <p>
  * The user to calculate the list for.
  * </p>
- * @param int $base_group_id <p>
+ * @param int $group_id <p>
  * Typically the group number from the password file.
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  */
-function posix_initgroups ($name, $base_group_id) {}
-
+#[Pure]
+function posix_initgroups(string $username, int $group_id): bool {}
 
 /**
  * Check whether the file exists.
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_F_OK', 0);
+define('POSIX_F_OK', 0);
 
 /**
  * Check whether the file exists and has execute permissions.
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_X_OK', 1);
+define('POSIX_X_OK', 1);
 
 /**
  * Check whether the file exists and has write permissions.
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_W_OK', 2);
+define('POSIX_W_OK', 2);
 
 /**
  * Check whether the file exists and has read permissions.
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_R_OK', 4);
+define('POSIX_R_OK', 4);
 
 /**
  * Normal file
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_S_IFREG', 32768);
+define('POSIX_S_IFREG', 32768);
 
 /**
  * Character special file
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_S_IFCHR', 8192);
+define('POSIX_S_IFCHR', 8192);
 
 /**
  * Block special file
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_S_IFBLK', 24576);
+define('POSIX_S_IFBLK', 24576);
 
 /**
  * FIFO (named pipe) special file
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_S_IFIFO', 4096);
+define('POSIX_S_IFIFO', 4096);
 
 /**
  * Socket
  * @link https://php.net/manual/en/posix.constants.php
  */
-define ('POSIX_S_IFSOCK', 49152);
+define('POSIX_S_IFSOCK', 49152);
 
 /**
  * The maximum size of the process's address space in bytes. See also PHP's memory_limit configuration directive.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_AS', 5);
+define('POSIX_RLIMIT_AS', 5);
 /**
  * The maximum size of a core file. If the limit is set to 0, no core file will be generated.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_CORE', 4);
+define('POSIX_RLIMIT_CORE', 4);
 
 /**
  * The maximum amount of CPU time that the process can use, in seconds.
@@ -757,7 +783,7 @@ define ('POSIX_RLIMIT_CORE', 4);
  * at which point an uncatchable SIGKILL signal is sent. See also set_time_limit().
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_CPU', 0);
+define('POSIX_RLIMIT_CPU', 0);
 
 /**
  * The maximum size of the process's data segment, in bytes.
@@ -765,13 +791,13 @@ define ('POSIX_RLIMIT_CPU', 0);
  * the execution of PHP unless an extension is in use that calls brk() or sbrk().
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_DATA', 2);
+define('POSIX_RLIMIT_DATA', 2);
 
 /**
  * The maximum size of files that the process can create, in bytes.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_FSIZE', 1);
+define('POSIX_RLIMIT_FSIZE', 1);
 
 /**
  * The maximum number of locks that the process can create.
@@ -817,40 +843,37 @@ define('POSIX_RLIMIT_SIGPENDING', 11);
  * The maximum number of bytes that can be locked into memory.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_MEMLOCK', 6);
+define('POSIX_RLIMIT_MEMLOCK', 6);
 
 /**
  * A value one greater than the maximum file descriptor number that can be opened by this process.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_NOFILE', 8);
+define('POSIX_RLIMIT_NOFILE', 8);
 
 /**
  * The maximum number of processes (and/or threads, on some operating systems)
  * that can be created for the real user ID of the process.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_NPROC', 7);
+define('POSIX_RLIMIT_NPROC', 7);
 
 /**
  * The maximum size of the process's resident set, in pages.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_RSS', 5);
+define('POSIX_RLIMIT_RSS', 5);
 
 /**
  * The maximum size of the process stack, in bytes.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_STACK', 3);
+define('POSIX_RLIMIT_STACK', 3);
 
 /**
  * Used to indicate an infinite value for a resource limit.
  * @link https://php.net/manual/en/posix.constants.setrlimit.php
  */
-define ('POSIX_RLIMIT_INFINITY', 9223372036854775807);
-
-
+define('POSIX_RLIMIT_INFINITY', 9223372036854775807);
 
 // End of posix v.
-?>
