@@ -1,9 +1,9 @@
 <?php
 
 use JetBrains\PhpStorm\Deprecated;
+use JetBrains\PhpStorm\ExpectedValues;
 use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
 use JetBrains\PhpStorm\Pure;
-use JetBrains\PhpStorm\ExpectedValues;
 
 /**
  * (PHP 5.5.0)<br/>
@@ -13,8 +13,7 @@ use JetBrains\PhpStorm\ExpectedValues;
  * @since 5.5
  */
 #[Pure]
-function boolval(mixed $value): bool
-{}
+function boolval(mixed $value): bool {}
 
 /**
  * Get the integer value of a variable
@@ -43,8 +42,7 @@ function boolval(mixed $value): bool
  * apply.
  */
 #[Pure]
-function intval (mixed $value, int $base = 10): int
-{}
+function intval(mixed $value, int $base = 10): int {}
 
 /**
  * Get float value of a variable
@@ -53,8 +51,7 @@ function intval (mixed $value, int $base = 10): int
  * @return float value of the given variable. Empty arrays return 0, non-empty arrays return 1.
  */
 #[Pure]
-function floatval (mixed $value): float
-{}
+function floatval(mixed $value): float {}
 
 /**
  * (PHP 4.2.0, PHP 5)<br/>
@@ -66,8 +63,7 @@ function floatval (mixed $value): float
  * @return float value of the given variable. Empty arrays return 0, non-empty arrays return 1.
  */
 #[Pure]
-function doubleval (mixed $value): float
-{}
+function doubleval(mixed $value): float {}
 
 /**
  * Get string value of a variable
@@ -82,8 +78,7 @@ function doubleval (mixed $value): float
  * @return string The string value of var.
  */
 #[Pure]
-function strval (mixed $value): string
-{}
+function strval(mixed $value): string {}
 
 /**
  * Get the type of a variable
@@ -107,20 +102,9 @@ function strval (mixed $value): string
  */
 #[Pure]
 #[ExpectedValues([
-    "boolean"
-    , "integer"
-    , "double"
-    , "string"
-    , "array"
-    , "object"
-    , "resource"
-    , "NULL"
-    , "unknown type"
-    , "resource (closed)"
+    "boolean", "integer", "double", "string", "array", "object", "resource", "NULL", "unknown type", "resource (closed)"
 ])]
-function gettype(mixed $value): string
-{
-}
+function gettype(mixed $value): string {}
 
 /**
  * Set the type of a variable
@@ -156,8 +140,7 @@ function gettype(mixed $value): string
  * </ul>
  * @return bool true on success or false on failure.
  */
-function settype (mixed &$var, #[ExpectedValues(["bool", "boolean", "int", "integer", "float", "double", "string", "array", "object", "null"])] string $type): bool
-{}
+function settype(mixed &$var, #[ExpectedValues(["bool", "boolean", "int", "integer", "float", "double", "string", "array", "object", "null"])] string $type): bool {}
 
 /**
  * Finds whether a variable is null.
@@ -169,8 +152,7 @@ function settype (mixed &$var, #[ExpectedValues(["bool", "boolean", "int", "inte
  * otherwise.
  */
 #[Pure]
-function is_null (mixed $value): bool
-{}
+function is_null(mixed $value): bool {}
 
 /**
  * Finds whether a variable is a resource
@@ -182,8 +164,7 @@ function is_null (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_resource (mixed $value): bool
-{}
+function is_resource(mixed $value): bool {}
 
 /**
  * Finds out whether a variable is a boolean
@@ -195,8 +176,7 @@ function is_resource (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_bool (mixed $value): bool
-{}
+function is_bool(mixed $value): bool {}
 
 /**
  * Alias:
@@ -209,8 +189,7 @@ function is_bool (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_long (mixed $value): bool
-{}
+function is_long(mixed $value): bool {}
 
 /**
  * Finds whether the type of a variable is float
@@ -222,8 +201,7 @@ function is_long (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_float (mixed $value): bool
-{}
+function is_float(mixed $value): bool {}
 
 /**
  * Find whether the type of a variable is integer
@@ -235,8 +213,7 @@ function is_float (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_int (mixed $value): bool
-{}
+function is_int(mixed $value): bool {}
 
 /**
  * Alias:
@@ -249,8 +226,7 @@ function is_int (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_integer (mixed $value): bool
-{}
+function is_integer(mixed $value): bool {}
 
 /**
  * Alias:
@@ -263,8 +239,7 @@ function is_integer (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_double (mixed $value): bool
-{}
+function is_double(mixed $value): bool {}
 
 /**
  * Alias:
@@ -278,8 +253,7 @@ function is_double (mixed $value): bool
  */
 #[Pure]
 #[Deprecated(since: '7.4')]
-function is_real (mixed $var): bool
-{}
+function is_real(mixed $var): bool {}
 
 /**
  * Finds whether a variable is a number or a numeric string
@@ -291,8 +265,7 @@ function is_real (mixed $var): bool
  * string, false otherwise.
  */
 #[Pure]
-function is_numeric (mixed $value): bool
-{}
+function is_numeric(mixed $value): bool {}
 
 /**
  * Find whether the type of a variable is string
@@ -304,8 +277,7 @@ function is_numeric (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_string (mixed $value): bool
-{}
+function is_string(mixed $value): bool {}
 
 /**
  * Finds whether a variable is an array
@@ -317,8 +289,7 @@ function is_string (mixed $value): bool
  * false otherwise.
  */
 #[Pure]
-function is_array (mixed $value): bool
-{}
+function is_array(mixed $value): bool {}
 
 /**
  * Finds whether a variable is an object
@@ -330,8 +301,7 @@ function is_array (mixed $value): bool
  * Since 7.2.0 returns true for unserialized objects without a class definition (class of <b>__PHP_Incomplete_Class</b>).
  */
 #[Pure]
-function is_object (mixed $value): bool
-{}
+function is_object(mixed $value): bool {}
 
 /**
  * Finds whether a variable is a scalar
@@ -343,8 +313,7 @@ function is_object (mixed $value): bool
  * otherwise.
  */
 #[Pure]
-function is_scalar (mixed $value): bool
-{}
+function is_scalar(mixed $value): bool {}
 
 /**
  * Verify that the contents of a variable can be called as a function
@@ -369,8 +338,7 @@ function is_scalar (mixed $value): bool
  * @return bool <b>TRUE</b> if $var is callable, <b>FALSE</b>
  * otherwise.
  */
-function is_callable (mixed $value, bool $syntax_only, &$callable_name): bool
-{}
+function is_callable(mixed $value, bool $syntax_only = false, &$callable_name): bool {}
 
 /**
  * Verify that the contents of a variable is a countable value
@@ -381,8 +349,7 @@ function is_callable (mixed $value, bool $syntax_only, &$callable_name): bool
  * @since 7.3
  */
 #[Pure]
-function is_countable(mixed $value): bool
-{}
+function is_countable(mixed $value): bool {}
 
 /**
  * Closes process file pointer
@@ -396,8 +363,7 @@ function is_countable(mixed $value): bool
  * If PHP has been compiled with <tt>--enable-sigchild</tt>, the return value of this function is undefined.
  * </p>
  */
-function pclose ($handle): int
-{}
+function pclose($handle): int {}
 
 /**
  * Opens process file pointer
@@ -418,8 +384,7 @@ function pclose ($handle): int
  * <p>
  * If an error occurs, returns false.
  */
-function popen (string $command, string $mode)
-{}
+function popen(string $command, string $mode) {}
 
 /**
  * Outputs a file
@@ -436,8 +401,7 @@ function popen (string $command, string $mode)
  * </p>
  * @return false|int the number of bytes read from the file, or FALSE on failure
  */
-function readfile (string $filename, bool $use_include_path, $context): int|false
-{}
+function readfile(string $filename, bool $use_include_path = false, $context): int|false {}
 
 /**
  * Rewind the position of a file pointer
@@ -448,8 +412,7 @@ function readfile (string $filename, bool $use_include_path, $context): int|fals
  * </p>
  * @return bool true on success or false on failure.
  */
-function rewind ($stream): bool
-{}
+function rewind($stream): bool {}
 
 /**
  * Removes directory
@@ -460,8 +423,7 @@ function rewind ($stream): bool
  * @param resource $context [optional]
  * @return bool true on success or false on failure.
  */
-function rmdir (string $directory, $context): bool
-{}
+function rmdir(string $directory, $context): bool {}
 
 /**
  * Changes the current umask
@@ -472,8 +434,7 @@ function rmdir (string $directory, $context): bool
  * @return int umask without arguments simply returns the
  * current umask otherwise the old umask is returned.
  */
-function umask (?int $mask): int
-{}
+function umask(?int $mask): int {}
 
 /**
  * Closes an open file pointer
@@ -484,8 +445,7 @@ function umask (?int $mask): int
  * </p>
  * @return bool true on success or false on failure.
  */
-function fclose ($stream): bool
-{}
+function fclose($stream): bool {}
 
 /**
  * Tests for end-of-file on a file pointer
@@ -494,8 +454,7 @@ function fclose ($stream): bool
  * @return bool true if the file pointer is at EOF or an error occurs
  * (including socket timeout); otherwise returns false.
  */
-function feof ($stream): bool
-{}
+function feof($stream): bool {}
 
 /**
  * Gets character from file pointer
@@ -504,8 +463,7 @@ function feof ($stream): bool
  * @return string|false a string containing a single character read from the file pointed
  * to by handle. Returns false on EOF.
  */
-function fgetc ($stream): string|false
-{}
+function fgetc($stream): string|false {}
 
 /**
  * Gets line from file pointer
@@ -529,8 +487,7 @@ function fgetc ($stream): string|false
  * <p>
  * If an error occurs, returns false.
  */
-function fgets ($stream, ?int $length): string|false
-{}
+function fgets($stream, ?int $length): string|false {}
 
 /**
  * Gets line from file pointer and strip HTML tags
@@ -552,8 +509,7 @@ function fgets ($stream, ?int $length): string|false
  * @removed 8.0
  */
 #[Deprecated(since: '7.3')]
-function fgetss ($handle, ?int $length = null, $allowable_tags = null): bool|string
-{}
+function fgetss($handle, ?int $length = null, $allowable_tags = null): false|string {}
 
 /**
  * Binary-safe file read
@@ -564,8 +520,7 @@ function fgetss ($handle, ?int $length = null, $allowable_tags = null): bool|str
  * </p>
  * @return string|false the read string or false on failure.
  */
-function fread ($stream, int $length): string|false
-{}
+function fread($stream, int $length): string|false {}
 
 /**
  * Opens file or URL
@@ -748,8 +703,7 @@ function fread ($stream, int $length): string|false
  * @param resource $context [optional]
  * @return resource|false a file pointer resource on success, or false on error.
  */
-function fopen (string $filename, string $mode, bool $use_include_path = false, $context)
-{}
+function fopen(string $filename, string $mode, bool $use_include_path = false, $context) {}
 
 /**
  * Output all remaining data on a file pointer
@@ -761,8 +715,7 @@ function fopen (string $filename, string $mode, bool $use_include_path = false,
  * and passed through to the output.
  */
 #[LanguageLevelTypeAware(["8.0" => "int"], default: "int|false")]
-function fpassthru ($stream)
-{}
+function fpassthru($stream) {}
 
 /**
  * Truncates a file to a given length
@@ -786,8 +739,7 @@ function fpassthru ($stream)
  * </p>
  * @return bool true on success or false on failure.
  */
-function ftruncate ($stream, int $size): bool
-{}
+function ftruncate($stream, int $size): bool {}
 
 /**
  * Gets information about a file using an open file pointer
@@ -796,8 +748,7 @@ function ftruncate ($stream, int $size): bool
  * @return array|false an array with the statistics of the file; the format of the array
  * is described in detail on the stat manual page.
  */
-function fstat ($stream): array|false
-{}
+function fstat($stream): array|false {}
 
 /**
  * Seeks on a file pointer
@@ -825,8 +776,7 @@ function fstat ($stream): array|false
  * @return int Upon success, returns 0; otherwise, returns -1. Note that seeking
  * past EOF is not considered an error.
  */
-function fseek ($stream, int $offset, int $whence = SEEK_SET): int
-{}
+function fseek($stream, int $offset, int $whence = SEEK_SET): int {}
 
 /**
  * Returns the current position of the file read/write pointer
@@ -843,8 +793,7 @@ function fseek ($stream, int $offset, int $whence = SEEK_SET): int
  * <p>
  * If an error occurs, returns false.
  */
-function ftell ($stream): int|false
-{}
+function ftell($stream): int|false {}
 
 /**
  * Flushes the output to a file
@@ -852,8 +801,7 @@ function ftell ($stream): int|false
  * @param resource $stream The file pointer must be valid, and must point to a file successfully opened by fopen() or fsockopen() (and not yet closed by fclose()).
  * @return bool true on success or false on failure.
  */
-function fflush ($stream): bool
-{}
+function fflush($stream): bool {}
 
 /**
  * Binary-safe file write
@@ -876,8 +824,7 @@ function fflush ($stream): bool
  * </p>
  * @return int|false the number of bytes written, or <b>FALSE</b> on error.
  */
-function fwrite ($stream, string $data, ?int $length): int|false
-{}
+function fwrite($stream, string $data, ?int $length): int|false {}
 
 /**
  * Alias:
@@ -903,8 +850,7 @@ function fwrite ($stream, string $data, ?int $length): int|false
  * @link https://php.net/manual/en/function.fputs.php
  * Binary-safe file write
  */
-function fputs ($stream, string $data, ?int $length): int|false
-{}
+function fputs($stream, string $data, ?int $length): int|false {}
 
 /**
  * Attempts to create the directory specified by pathname.
@@ -932,8 +878,7 @@ function fputs ($stream, string $data, ?int $length): int|false
  * @param resource $context [optional]
  * @return bool true on success or false on failure.
  */
-function mkdir (string $directory, int $permissions = 0777, bool $recursive = false, $context): bool
-{}
+function mkdir(string $directory, int $permissions = 0777, bool $recursive = false, $context): bool {}
 
 /**
  * Renames a file or directory
@@ -951,8 +896,7 @@ function mkdir (string $directory, int $permissions = 0777, bool $recursive = fa
  * @param resource $context [optional]
  * @return bool true on success or false on failure.
  */
-function rename (string $from, string $to, $context): bool
-{}
+function rename(string $from, string $to, $context): bool {}
 
 /**
  * Copies file
@@ -974,8 +918,7 @@ function rename (string $from, string $to, $context): bool
  * </p>
  * @return bool true on success or false on failure.
  */
-function copy (string $from, string $to, $context): bool
-{}
+function copy(string $from, string $to, $context): bool {}
 
 /**
  * Create file with unique file name
@@ -990,8 +933,7 @@ function copy (string $from, string $to, $context): bool
  * @return string|false the new temporary filename, or false on
  * failure.
  */
-function tempnam (string $directory, string $prefix): string|false
-{}
+function tempnam(string $directory, string $prefix): string|false {}
 
 /**
  * Creates a temporary file
@@ -999,8 +941,7 @@ function tempnam (string $directory, string $prefix): string|false
  * @return resource|false a file handle, similar to the one returned by
  * fopen, for the new file or false on failure.
  */
-function tmpfile ()
-{}
+function tmpfile() {}
 
 /**
  * Reads entire file into an array
@@ -1027,8 +968,7 @@ function tmpfile ()
  * present.
  * </p>
  */
-function file (string $filename, int $flags, $context): array|false
-{}
+function file(string $filename, int $flags, $context): array|false {}
 
 /**
  * Reads entire file into a string
@@ -1054,8 +994,7 @@ function file (string $filename, int $flags, $context): array|false
  * </p>
  * @return string|false The function returns the read data or false on failure.
  */
-function file_get_contents (string $filename, bool $use_include_path = false, $context, int $offset = 0, ?int $length): string|false
-{}
+function file_get_contents(string $filename, bool $use_include_path = false, $context, int $offset = 0, ?int $length): string|false {}
 
 /**
  * Write a string to a file
@@ -1128,5 +1067,4 @@ function file_get_contents (string $filename, bool $use_include_path = false, $c
  * @return int|false The function returns the number of bytes that were written to the file, or
  * false on failure.
  */
-function file_put_contents (string $filename, mixed $data, int $flags = 0, $context): int|false
-{}
+function file_put_contents(string $filename, mixed $data, int $flags = 0, $context): int|false {}
