@@ -3,13 +3,17 @@
 /**
  * @since 5.6
  */
-define ("ARRAY_FILTER_USE_BOTH", 1);
+
+use JetBrains\PhpStorm\Internal\LanguageLevelTypeAware;
+use JetBrains\PhpStorm\Internal\PhpStormStubsElementAvailable;
+use JetBrains\PhpStorm\Pure;
+
+define("ARRAY_FILTER_USE_BOTH", 1);
 
 /**
  * @since 5.6
  */
-define ("ARRAY_FILTER_USE_KEY", 2);
-
+define("ARRAY_FILTER_USE_KEY", 2);
 
 /**
  * Merge two or more arrays recursively
@@ -17,8 +21,8 @@ define ("ARRAY_FILTER_USE_KEY", 2);
  * @param array ...$arrays [optional] Variable list of arrays to recursively merge.
  * @return array An array of values resulted from merging the arguments together.
  */
-function array_merge_recursive(array ...$arrays) { }
-
+#[Pure]
+function array_merge_recursive(array ...$arrays): array {}
 
 /**
  * array_replace() replaces the values of the first array with the same values from all the following arrays.
@@ -31,12 +35,13 @@ function array_merge_recursive(array ...$arrays) { }
  * @param array $array <p>
  * The array in which elements are replaced.
  * </p>
- * @param array ...$arrays <p>
+ * @param array ...$replacements <p>
  * The array from which elements will be extracted.
  * </p>
  * @return array or null if an error occurs.
  */
-function array_replace(array $array, array ...$arrays) { }
+#[Pure]
+function array_replace(array $array, array ...$replacements): array {}
 
 /**
  * Replaces elements from passed arrays into the first array recursively
@@ -44,62 +49,67 @@ function array_replace(array $array, array ...$arrays) { }
  * @param array $array <p>
  * The array in which elements are replaced.
  * </p>
- * @param array ...$arrays <p>
+ * @param array ...$replacements <p>
  * The array from which elements will be extracted.
  * </p>
- * @return array an array, or &null; if an error occurs.
+ * @return array an array, or null if an error occurs.
  */
-function array_replace_recursive(array $array, array ...$arrays) { }
+#[Pure]
+function array_replace_recursive(array $array, array ...$replacements): array {}
 
 /**
- * Return all the keys of an array
+ * Return all the keys or a subset of the keys of an array
  * @link https://php.net/manual/en/function.array-keys.php
- * @param array $input <p>
+ * @param array $array <p>
  * An array containing keys to return.
  * </p>
- * @param mixed $search_value [optional] <p>
+ * @param mixed $filter_value [optional] <p>
  * If specified, then only keys containing these values are returned.
  * </p>
  * @param bool $strict [optional] <p>
  * Determines if strict comparison (===) should be used during the search.
  * </p>
- * @return array an array of all the keys in input.
+ * @return int[]|string[] an array of all the keys in input.
  */
-function array_keys(array $input, $search_value = null, $strict = null) { }
+#[Pure]
+function array_keys(array $array, mixed $filter_value, bool $strict = false): array {}
 
 /**
  * Return all the values of an array
  * @link https://php.net/manual/en/function.array-values.php
- * @param array $input <p>
+ * @param array $array <p>
  * The array.
  * </p>
  * @return array an indexed array of values.
  * @meta
  */
-function array_values(array $input) { }
+#[Pure]
+function array_values(array $array): array {}
 
 /**
  * Counts all the values of an array
  * @link https://php.net/manual/en/function.array-count-values.php
- * @param array $input <p>
+ * @param array $array <p>
  * The array of values to count
  * </p>
  * @return array an associative array of values from input as
  * keys and their count as value.
  */
-function array_count_values(array $input) { }
+#[Pure]
+function array_count_values(array $array): array {}
 
 /**
  * (PHP 5 &gt;=5.5.0)<br/>
  * Return the values from a single column in the input array
  * @link https://secure.php.net/manual/en/function.array-column.php
  * @param array $array <p>A multi-dimensional array (record set) from which to pull a column of values.</p>
- * @param mixed $column <p>The column of values to return. This value may be the integer key of the column you wish to retrieve, or it may be the string key name for an associative array. It may also be NULL to return complete arrays (useful together with index_key to reindex the array).</p>
- * @param mixed $index_key [optional] <p>The column to use as the index/keys for the returned array. This value may be the integer key of the column, or it may be the string key name.</p>
+ * @param string|int|null $column_key <p>The column of values to return. This value may be the integer key of the column you wish to retrieve, or it may be the string key name for an associative array. It may also be NULL to return complete arrays (useful together with index_key to reindex the array).</p>
+ * @param string|int|null $index_key [optional] <p>The column to use as the index/keys for the returned array. This value may be the integer key of the column, or it may be the string key name.</p>
  * @return array Returns an array of values representing a single column from the input array.
  * @since 5.5
  */
-function array_column(array $array, $column, $index_key = null) { }
+#[Pure]
+function array_column(array $array, string|int|null $column_key, string|int|null $index_key = null): array {}
 
 /**
  * Return an array with elements in reverse order
@@ -113,15 +123,16 @@ function array_column(array $array, $column, $index_key = null) { }
  * @return array the reversed array.
  * @meta
  */
-function array_reverse(array $array, $preserve_keys = null) { }
+#[Pure]
+function array_reverse(array $array, bool $preserve_keys = false): array {}
 
 /**
  * Iteratively reduce the array to a single value using a callback function
  * @link https://php.net/manual/en/function.array-reduce.php
- * @param array $input <p>
+ * @param array $array <p>
  * The input array.
  * </p>
- * @param callback $function <p>
+ * @param callback $callback <p>
  * The callback function. Signature is <pre>callback ( mixed $carry , mixed $item ) : mixed</pre>
  * <blockquote>mixed <var>$carry</var> <p>The return value of the previous iteration; on the first iteration it holds the value of <var>$initial</var>.</p></blockquote>
  * <blockquote>mixed <var>$item</var> <p>Holds the current iteration value of the <var>$input</var></p></blockquote>
@@ -132,7 +143,6 @@ function array_reverse(array $array, $preserve_keys = null) { }
  * the array is empty.
  * </p>
  * @return mixed the resulting value.
- * </p>
  * <p>
  * If the array is empty and initial is not passed,
  * array_reduce returns null.
@@ -143,20 +153,21 @@ function array_reverse(array $array, $preserve_keys = null) { }
  * <blockquote><pre>array_reduce(['2', '3', '4'], function($ax, $dx) { return $ax . ", {$dx}"; }, '1')  // Returns '1, 2, 3, 4'</pre></blockquote>
  * <blockquote><pre>array_reduce(['2', '3', '4'], function($ax, $dx) { return $ax + (int)$dx; }, 1)  // Returns 10</pre></blockquote>
  * <br/>
+ * </p>
  * @meta
  */
-function array_reduce(array $input, $function, $initial = null) { }
+function array_reduce(array $array, callable $callback, mixed $initial): mixed {}
 
 /**
  * Pad array to the specified length with a value
  * @link https://php.net/manual/en/function.array-pad.php
- * @param array $input <p>
+ * @param array $array <p>
  * Initial array of values to pad.
  * </p>
- * @param int $pad_size <p>
+ * @param int $length <p>
  * New size of the array.
  * </p>
- * @param mixed $pad_value <p>
+ * @param mixed $value <p>
  * Value to pad if input is less than
  * pad_size.
  * </p>
@@ -167,22 +178,24 @@ function array_reduce(array $input, $function, $initial = null) { }
  * on the left. If the absolute value of pad_size is less than or equal to
  * the length of the input then no padding takes place.
  */
-function array_pad(array $input, $pad_size, $pad_value) { }
+#[Pure]
+function array_pad(array $array, int $length, mixed $value): array {}
 
 /**
  * Exchanges all keys with their associated values in an array
  * @link https://php.net/manual/en/function.array-flip.php
- * @param array $array <p>
+ * @param int[]|string[] $array <p>
  * An array of key/value pairs to be flipped.
  * </p>
- * @return array Returns the flipped array.
+ * @return int[]|string[] Returns the flipped array.
  */
-function array_flip(array $array) { }
+#[Pure]
+function array_flip(array $array): array {}
 
 /**
- * Changes all keys in an array
+ * Changes the case of all keys in an array
  * @link https://php.net/manual/en/function.array-change-key-case.php
- * @param array $input <p>
+ * @param array $array <p>
  * The array to work on
  * </p>
  * @param int $case [optional] <p>
@@ -192,15 +205,16 @@ function array_flip(array $array) { }
  * @return array an array with its keys lower or uppercased
  * @meta
  */
-function array_change_key_case(array $input, $case = null) { }
+#[Pure]
+function array_change_key_case(array $array, int $case): array {}
 
 /**
- * Pick one or more random entries out of an array
+ * Pick one or more random keys out of an array
  * @link https://php.net/manual/en/function.array-rand.php
- * @param array $input <p>
+ * @param array $array <p>
  * The input array.
  * </p>
- * @param int $num_req [optional] <p>
+ * @param int $num [optional] <p>
  * Specifies how many entries you want to pick.
  * </p>
  * @return int|string|array If you are picking only one entry, array_rand
@@ -208,7 +222,8 @@ function array_change_key_case(array $input, $case = null) { }
  * of keys for the random entries. This is done so that you can pick
  * random keys as well as values out of the array.
  */
-function array_rand(array $input, $num_req = null) { }
+#[Pure]
+function array_rand(array $array, int $num = 1): array|string|int {}
 
 /**
  * Removes duplicate values from an array
@@ -216,7 +231,7 @@ function array_rand(array $input, $num_req = null) { }
  * @param array $array <p>
  * The input array.
  * </p>
- * @param int $sort_flags [optional] <p>
+ * @param int $flags [optional] <p>
  * The optional second parameter sort_flags
  * may be used to modify the sorting behavior using these values:
  * </p>
@@ -241,40 +256,61 @@ function array_rand(array $input, $num_req = null) { }
  * @return array the filtered array.
  * @meta
  */
-function array_unique(array $array, $sort_flags = SORT_STRING) { }
+#[Pure]
+function array_unique(array $array, int $flags = SORT_STRING): array {}
+
+/**
+ * Computes the intersection of arrays
+ * @link https://php.net/manual/en/function.array-intersect.php
+ * @param array $array <p>
+ * The array with main values to check.
+ * </p>
+ * @param array ...$arrays <p>
+ * An array to compare values against.
+ * </p>
+ * @return array an array containing all of the values in
+ * array1 whose values exist in all of the parameters.
+ * @meta
+ */
+#[Pure]
+#[PhpStormStubsElementAvailable('8.0')]
+function array_intersect(array $array, array ...$arrays): array {}
 
 /**
  * Computes the intersection of arrays
  * @link https://php.net/manual/en/function.array-intersect.php
  * @param array $array1 <p>
- * The array with master values to check.
+ * The array with main values to check.
  * </p>
  * @param array $array2 <p>
  * An array to compare values against.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @return array an array containing all of the values in
  * array1 whose values exist in all of the parameters.
  * @meta
  */
-function array_intersect(array $array1, array $array2, array $_ = null) { }
+#[Pure]
+#[PhpStormStubsElementAvailable(to: '7.4')]
+function array_intersect(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the intersection of arrays using keys for comparison
  * @link https://php.net/manual/en/function.array-intersect-key.php
  * @param array $array1 <p>
- * The array with master keys to check.
+ * The array with main keys to check.
  * </p>
  * @param array $array2 <p>
  * An array to compare keys against.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @return array an associative array containing all the entries of
  * array1 which have keys that are present in all
  * arguments.
  * @meta
  */
-function array_intersect_key(array $array1, array $array2, array $_ = null) { }
+#[Pure]
+function array_intersect_key(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the intersection of arrays using a callback function on the keys for comparison
@@ -285,7 +321,7 @@ function array_intersect_key(array $array1, array $array2, array $_ = null) { }
  * @param array $array2 <p>
  * First array to compare keys against.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $key_compare_func <p>
  * User supplied callback function to do the comparison.
  * </p>
@@ -293,7 +329,7 @@ function array_intersect_key(array $array1, array $array2, array $_ = null) { }
  * in all the arguments.
  * @meta
  */
-function array_intersect_ukey(array $array1, array $array2, array $_ = null, $key_compare_func) { }
+function array_intersect_ukey(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
  * Computes the intersection of arrays, compares data by a callback function
@@ -304,7 +340,7 @@ function array_intersect_ukey(array $array1, array $array2, array $_ = null, $ke
  * @param array $array2 <p>
  * The second array.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $data_compare_func <p>
  * The callback comparison function.
  * </p>
@@ -318,13 +354,13 @@ function array_intersect_ukey(array $array1, array $array2, array $_ = null, $ke
  * that are present in all the arguments.
  * @meta
  */
-function array_uintersect(array $array1, array $array2, array $_ = null, $data_compare_func) { }
+function array_uintersect(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the intersection of arrays with additional index check
  * @link https://php.net/manual/en/function.array-intersect-assoc.php
  * @param array $array1 <p>
- * The array with master values to check.
+ * The array with main values to check.
  * </p>
  * @param array $array2 <p>
  * An array to compare values against.
@@ -334,7 +370,8 @@ function array_uintersect(array $array1, array $array2, array $_ = null, $data_c
  * array1 that are present in all of the arguments.
  * @meta
  */
-function array_intersect_assoc(array $array1, array $array2, array $_ = null) { }
+#[Pure]
+function array_intersect_assoc(array $array1, array $array2, array $_ = null): array {}
 
 /**
  * Computes the intersection of arrays with additional index check, compares data by a callback function
@@ -345,7 +382,7 @@ function array_intersect_assoc(array $array1, array $array2, array $_ = null) {
  * @param array $array2 <p>
  * The second array.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $data_compare_func <p>
  * For comparison is used the user supplied callback function.
  * It must return an integer less than, equal
@@ -357,7 +394,7 @@ function array_intersect_assoc(array $array1, array $array2, array $_ = null) {
  * array1 that are present in all the arguments.
  * @meta
  */
-function array_uintersect_assoc(array $array1, array $array2, array $_ = null, $data_compare_func) { }
+function array_uintersect_assoc(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the intersection of arrays with additional index check, compares indexes by a callback function
@@ -368,7 +405,7 @@ function array_uintersect_assoc(array $array1, array $array2, array $_ = null, $
  * @param array $array2 <p>
  * First array to compare keys against.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $key_compare_func <p>
  * User supplied callback function to do the comparison.
  * </p>
@@ -376,10 +413,10 @@ function array_uintersect_assoc(array $array1, array $array2, array $_ = null, $
  * in all of the arguments.
  * @meta
  */
-function array_intersect_uassoc(array $array1, array $array2, array $_ = null, $key_compare_func) { }
+function array_intersect_uassoc(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
- * Computes the intersection of arrays with additional index check, compares data and indexes by a callback functions
+ * Computes the intersection of arrays with additional index check, compares data and indexes by separate callback functions
  * @link https://php.net/manual/en/function.array-uintersect-uassoc.php
  * @param array $array1 <p>
  * The first array.
@@ -387,7 +424,7 @@ function array_intersect_uassoc(array $array1, array $array2, array $_ = null, $
  * @param array $array2 <p>
  * The second array.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $data_compare_func <p>
  * For comparison is used the user supplied callback function.
  * It must return an integer less than, equal
@@ -402,7 +439,25 @@ function array_intersect_uassoc(array $array1, array $array2, array $_ = null, $
  * array1 that are present in all the arguments.
  * @meta
  */
-function array_uintersect_uassoc(array $array1, array $array2, array $_ = null, $data_compare_func, $key_compare_func) { }
+#[Pure]
+function array_uintersect_uassoc(array $array1, array $array2, array $_ = null, callable $data_compare_func, callable $key_compare_func): array {}
+
+/**
+ * Computes the difference of arrays
+ * @link https://php.net/manual/en/function.array-diff.php
+ * @param array $array <p>
+ * The array to compare from
+ * </p>
+ * @param array ...$excludes <p>
+ * An array to compare against
+ * </p>
+ * @return array an array containing all the entries from
+ * array1 that are not present in any of the other arrays.
+ * @meta
+ */
+#[Pure]
+#[PhpStormStubsElementAvailable('8.0')]
+function array_diff(array $array, array ...$excludes): array {}
 
 /**
  * Computes the difference of arrays
@@ -413,12 +468,14 @@ function array_uintersect_uassoc(array $array1, array $array2, array $_ = null,
  * @param array $array2 <p>
  * An array to compare against
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @return array an array containing all the entries from
  * array1 that are not present in any of the other arrays.
  * @meta
  */
-function array_diff(array $array1, array $array2, array $_ = null) { }
+#[Pure]
+#[PhpStormStubsElementAvailable(to: '7.4')]
+function array_diff(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the difference of arrays using keys for comparison
@@ -429,13 +486,14 @@ function array_diff(array $array1, array $array2, array $_ = null) { }
  * @param array $array2 <p>
  * An array to compare against
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @return array an array containing all the entries from
  * array1 whose keys are not present in any of the
  * other arrays.
  * @meta
  */
-function array_diff_key(array $array1, array $array2, array $_ = null) { }
+#[Pure]
+function array_diff_key(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the difference of arrays using a callback function on the keys for comparison
@@ -446,7 +504,7 @@ function array_diff_key(array $array1, array $array2, array $_ = null) { }
  * @param array $array2 <p>
  * An array to compare against
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $key_compare_func <p>
  * callback function to use.
  * The callback function must return an integer less than, equal
@@ -457,7 +515,7 @@ function array_diff_key(array $array1, array $array2, array $_ = null) { }
  * array1 that are not present in any of the other arrays.
  * @meta
  */
-function array_diff_ukey(array $array1, array $array2, array $_ = null, $key_compare_func) { }
+function array_diff_ukey(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
  * Computes the difference of arrays by using a callback function for data comparison
@@ -468,7 +526,7 @@ function array_diff_ukey(array $array1, array $array2, array $_ = null, $key_com
  * @param array $array2 <p>
  * The second array.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $data_compare_func <p>
  * The callback comparison function.
  * </p>
@@ -482,7 +540,7 @@ function array_diff_ukey(array $array1, array $array2, array $_ = null, $key_com
  * that are not present in any of the other arguments.
  * @meta
  */
-function array_udiff(array $array1, array $array2, array $_ = null, $data_compare_func) { }
+function array_udiff(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the difference of arrays with additional index check
@@ -493,12 +551,13 @@ function array_udiff(array $array1, array $array2, array $_ = null, $data_compar
  * @param array $array2 <p>
  * An array to compare against
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @return array an array containing all the values from
  * array1 that are not present in any of the other arrays.
  * @meta
  */
-function array_diff_assoc(array $array1, array $array2, array $_ = null) { }
+#[Pure]
+function array_diff_assoc(array $array1, array $array2, array ...$_): array {}
 
 /**
  * Computes the difference of arrays with additional index check, compares data by a callback function
@@ -509,7 +568,7 @@ function array_diff_assoc(array $array1, array $array2, array $_ = null) { }
  * @param array $array2 <p>
  * The second array.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $data_compare_func <p>
  * The callback comparison function.
  * </p>
@@ -530,7 +589,7 @@ function array_diff_assoc(array $array1, array $array2, array $_ = null) { }
  * comparison.
  * @meta
  */
-function array_udiff_assoc(array $array1, array $array2, array $_ = null, $data_compare_func) { }
+function array_udiff_assoc(array $array1, array $array2, array $_ = null, callable $data_compare_func): array {}
 
 /**
  * Computes the difference of arrays with additional index check which is performed by a user supplied callback function
@@ -541,7 +600,7 @@ function array_udiff_assoc(array $array1, array $array2, array $_ = null, $data_
  * @param array $array2 <p>
  * An array to compare against
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $key_compare_func <p>
  * callback function to use.
  * The callback function must return an integer less than, equal
@@ -552,7 +611,7 @@ function array_udiff_assoc(array $array1, array $array2, array $_ = null, $data_
  * array1 that are not present in any of the other arrays.
  * @meta
  */
-function array_diff_uassoc(array $array1, array $array2, array $_ = null, $key_compare_func) { }
+function array_diff_uassoc(array $array1, array $array2, array $_ = null, callable $key_compare_func): array {}
 
 /**
  * Computes the difference of arrays with additional index check, compares data and indexes by a callback function
@@ -563,7 +622,7 @@ function array_diff_uassoc(array $array1, array $array2, array $_ = null, $key_c
  * @param array $array2 <p>
  * The second array.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$_ [optional]
  * @param callback $data_compare_func <p>
  * The callback comparison function.
  * </p>
@@ -591,7 +650,7 @@ function array_diff_uassoc(array $array1, array $array2, array $_ = null, $key_c
  * arguments.
  * @meta
  */
-function array_udiff_uassoc(array $array1, array $array2, array $_ = null, $data_compare_func, $key_compare_func) { }
+function array_udiff_uassoc(array $array1, array $array2, array $_ = null, callable $data_compare_func, callable $key_compare_func): array {}
 
 /**
  * Calculate the sum of values in an array
@@ -601,7 +660,8 @@ function array_udiff_uassoc(array $array1, array $array2, array $_ = null, $data
  * </p>
  * @return int|float the sum of values as an integer or float.
  */
-function array_sum(array $array) { }
+#[Pure]
+function array_sum(array $array): int|float {}
 
 /**
  * Calculate the product of values in an array
@@ -611,7 +671,8 @@ function array_sum(array $array) { }
  * </p>
  * @return int|float the product as an integer or float.
  */
-function array_product(array $array) { }
+#[Pure]
+function array_product(array $array): int|float {}
 
 /**
  * Iterates over each value in the <b>array</b>
@@ -620,10 +681,10 @@ function array_product(array $array) { }
  * current value from <b>array</b> is returned into
  * the result array. Array keys are preserved.
  * @link https://php.net/manual/en/function.array-filter.php
- * @param array $input <p>
+ * @param array $array <p>
  * The array to iterate over
  * </p>
- * @param callback $callback [optional] <p>
+ * @param callback|null $callback [optional] <p>
  * The callback function to use
  * </p>
  * <p>
@@ -632,7 +693,7 @@ function array_product(array $array) { }
  * converting to
  * boolean) will be removed.
  * </p>
- * @param int $flag [optional] <p>
+ * @param int $mode [optional] <p>
  * Flag determining what arguments are sent to <i>callback</i>:
  * </p><ul>
  * <li>
@@ -647,7 +708,7 @@ function array_product(array $array) { }
  * @return array the filtered array.
  * @meta
  */
-function array_filter(array $input, $callback = null, $flag = 0) { }
+function array_filter(array $array, ?callable $callback, int $mode = 0): array {}
 
 /**
  * Applies the callback to the elements of the given arrays
@@ -655,23 +716,23 @@ function array_filter(array $input, $callback = null, $flag = 0) { }
  * @param callback $callback <p>
  * Callback function to run for each element in each array.
  * </p>
- * @param array $arr1 <p>
+ * @param array $array <p>
  * An array to run through the callback function.
  * </p>
- * @param array $_ [optional]
+ * @param array ...$arrays [optional]
  * @return array an array containing all the elements of arr1
  * after applying the callback function to each one.
  * @meta
  */
-function array_map($callback, array $arr1, array $_ = null) { }
+function array_map(callable $callback, array $array, array ...$arrays): array {}
 
 /**
  * Split an array into chunks
  * @link https://php.net/manual/en/function.array-chunk.php
- * @param array $input <p>
+ * @param array $array <p>
  * The array to work on
  * </p>
- * @param int $size <p>
+ * @param int $length <p>
  * The size of each chunk
  * </p>
  * @param bool $preserve_keys [optional] <p>
@@ -681,7 +742,8 @@ function array_map($callback, array $arr1, array $_ = null) { }
  * @return array a multidimensional numerically indexed array, starting with zero,
  * with each dimension containing size elements.
  */
-function array_chunk(array $input, $size, $preserve_keys = null) { }
+#[Pure]
+function array_chunk(array $array, int $length, bool $preserve_keys = false): array {}
 
 /**
  * Creates an array by using one array for keys and another for its values
@@ -697,20 +759,23 @@ function array_chunk(array $input, $size, $preserve_keys = null) { }
  * for each array isn't equal or if the arrays are empty.
  * @meta
  */
-function array_combine(array $keys, array $values) { }
+#[Pure]
+#[LanguageLevelTypeAware(["8.0" => "array"], default: "array|false")]
+function array_combine(array $keys, array $values) {}
 
 /**
  * Checks if the given key or index exists in the array
  * @link https://php.net/manual/en/function.array-key-exists.php
- * @param mixed $key <p>
+ * @param int|string $key <p>
  * Value to check.
  * </p>
- * @param array|ArrayObject $search <p>
+ * @param array|ArrayObject $array <p>
  * An array with keys to check.
  * </p>
  * @return bool true on success or false on failure.
  */
-function array_key_exists($key, array $search) { }
+#[Pure]
+function array_key_exists($key, #[LanguageLevelTypeAware(["8.0" => "array"], default: "array|ArrayObject")] $array): bool {}
 
 /**
  * Gets the first key of an array
@@ -722,7 +787,8 @@ function array_key_exists($key, array $search) { }
  * @return string|int|null Returns the first key of array if the array is not empty; NULL otherwise.
  * @since 7.3
  */
-function array_key_first(array $array) { }
+#[Pure]
+function array_key_first(array $array): string|int|null {}
 
 /**
  * Gets the last key of an array
@@ -734,41 +800,48 @@ function array_key_first(array $array) { }
  * @return string|int|null Returns the last key of array if the array is not empty; NULL otherwise.
  * @since 7.3
  */
-function array_key_last(array $array) { }
+#[Pure]
+function array_key_last(array $array): string|int|null {}
 
 /**
- * &Alias; <function>current</function>
+ * Alias:
+ * {@see current}
  * @link https://php.net/manual/en/function.pos.php
- * @param array $arg
+ * @param array|ArrayAccess $array
+ * @return mixed
  */
-function pos($arg) { }
+#[Pure]
+function pos(object|array $array): mixed {}
 
 /**
- * &Alias; <function>count</function>
+ * Alias:
+ * {@see \count}
  * @link https://php.net/manual/en/function.sizeof.php
- * @param array|Countable $var
+ * @param array|Countable $value
  * @param int $mode [optional]
  * @return int
  */
-function sizeof($var, $mode = COUNT_NORMAL) { }
+#[Pure]
+function sizeof(Countable|array $value, int $mode = COUNT_NORMAL): int {}
 
 /**
  * Checks if the given key or index exists in the array. The name of this function is array_key_exists() in PHP > 4.0.6.
  * @link https://php.net/manual/en/function.array-key-exists.php
- * @param mixed $key <p>
+ * @param int|string $key <p>
  * Value to check.
  * </p>
- * @param array $search <p>
+ * @param array $array <p>
  * An array with keys to check.
  * </p>
  * @return bool true on success or false on failure.
  */
-function key_exists($key, $search) { }
+#[Pure]
+function key_exists($key, array $array): bool {}
 
 /**
- * Checks if assertion is &false;
+ * Checks if assertion is <b>FALSE</b>
  * @link https://php.net/manual/en/function.assert.php
- * @param mixed $assertion <p>
+ * @param Throwable|string|null $assertion <p>
  * The assertion.
  * In PHP 5, this must be either a string to be evaluated or a boolean to be tested.
  * In PHP 7, this may also be any expression that returns a value,
@@ -779,21 +852,19 @@ function key_exists($key, $search) { }
  * <p>An optional description that will be included in the failure message if the assertion fails.</p>
  * @return bool false if the assertion is false, true otherwise.
  */
-function assert($assertion, $description = '') { }
+function assert(mixed $assertion, $description = ''): bool {}
 
 /**
  * AssertionError is thrown when an assertion made via {@see assert()} fails.
  * @link https://php.net/manual/en/class.assertionerror.php
  * @since 7.0
  */
-class AssertionError extends Error {
-
-}
+class AssertionError extends Error {}
 
 /**
  * Set/get the various assert flags
  * @link https://php.net/manual/en/function.assert-options.php
- * @param int $what <p>
+ * @param int $option <p>
  * <table>
  * Assert Options
  * <tr valign="top">
@@ -840,9 +911,9 @@ class AssertionError extends Error {
  * @param mixed $value [optional] <p>
  * An optional new value for the option.
  * </p>
- * @return mixed the original setting of any option or false on errors.
+ * @return object|array|string|int|null The original setting of any option.
  */
-function assert_options($what, $value = null) { }
+function assert_options(int $option, mixed $value): object|array|string|int|null {}
 
 /**
  * Compares two "PHP-standardized" version number strings
@@ -853,7 +924,7 @@ function assert_options($what, $value = null) { }
  * @param string $version2 <p>
  * Second version number.
  * </p>
- * @param string $operator [optional] <p>
+ * @param string|null $operator [optional] <p>
  * If you specify the third optional operator
  * argument, you can test for a particular relationship. The
  * possible operators are: &lt;,
@@ -878,31 +949,33 @@ function assert_options($what, $value = null) { }
  * function will return true if the relationship is the one specified
  * by the operator, false otherwise.
  */
-function version_compare($version1, $version2, $operator = null) { }
+function version_compare(string $version1, string $version2, ?string $operator): int|bool {}
 
 /**
  * Convert a pathname and a project identifier to a System V IPC key
  * @link https://php.net/manual/en/function.ftok.php
- * @param string $pathname <p>
+ * @param string $filename <p>
  * Path to an accessible file.
  * </p>
- * @param string $proj <p>
+ * @param string $project_id <p>
  * Project identifier. This must be a one character string.
  * </p>
  * @return int On success the return value will be the created key value, otherwise
  * -1 is returned.
  */
-function ftok($pathname, $proj) { }
+#[Pure]
+function ftok(string $filename, string $project_id): int {}
 
 /**
  * Perform the rot13 transform on a string
  * @link https://php.net/manual/en/function.str-rot13.php
- * @param string $str <p>
+ * @param string $string <p>
  * The input string.
  * </p>
  * @return string the ROT13 version of the given string.
  */
-function str_rot13($str) { }
+#[Pure]
+function str_rot13(string $string): string {}
 
 /**
  * Retrieve list of registered filters
@@ -910,24 +983,26 @@ function str_rot13($str) { }
  * @return array an indexed array containing the name of all stream filters
  * available.
  */
-function stream_get_filters() { }
+#[Pure]
+function stream_get_filters(): array {}
 
 /**
  * Check if a stream is a TTY
  * @link https://php.net/manual/en/function.stream-isatty.php
- * @param resource $name
+ * @param resource $stream
  * @return bool
  * @since 7.2
  */
-function stream_isatty($name) {}
+#[Pure]
+function stream_isatty($stream): bool {}
 
 /**
  * Register a user defined stream filter
  * @link https://php.net/manual/en/function.stream-filter-register.php
- * @param string $filtername <p>
+ * @param string $filter_name <p>
  * The filter name to be registered.
  * </p>
- * @param string $classname <p>
+ * @param string $class <p>
  * To implement a filter, you need to define a class as an extension of
  * php_user_filter with a number of member functions
  * as defined below. When performing read/write operations on the stream
@@ -1030,29 +1105,29 @@ function stream_isatty($name) {}
  * this would be the time to destroy or dispose of them.
  * </p>
  * @return bool true on success or false on failure.
- * </p>
  * <p>
  * stream_filter_register will return false if the
  * filtername is already defined.
+ * </p>
  */
-function stream_filter_register($filtername, $classname) { }
+function stream_filter_register(string $filter_name, string $class): bool {}
 
 /**
  * Return a bucket object from the brigade for operating on
  * @link https://php.net/manual/en/function.stream-bucket-make-writeable.php
  * @param resource $brigade
- * @return object
+ * @return object|null
  */
-function stream_bucket_make_writeable($brigade) { }
+function stream_bucket_make_writeable($brigade): ?object {}
 
 /**
  * Prepend bucket to brigade
  * @link https://php.net/manual/en/function.stream-bucket-prepend.php
  * @param resource $brigade
- * @param resource $bucket
+ * @param object $bucket
  * @return void
  */
-function stream_bucket_prepend($brigade, $bucket) { }
+function stream_bucket_prepend($brigade, object $bucket): void {}
 
 /**
  * Append bucket to brigade
@@ -1061,7 +1136,7 @@ function stream_bucket_prepend($brigade, $bucket) { }
  * @param object $bucket
  * @return void
  */
-function stream_bucket_append($brigade, $bucket) { }
+function stream_bucket_append($brigade, object $bucket): void {}
 
 /**
  * Create a new bucket for use on the current stream
@@ -1070,7 +1145,7 @@ function stream_bucket_append($brigade, $bucket) { }
  * @param string $buffer
  * @return object
  */
-function stream_bucket_new($stream, $buffer) { }
+function stream_bucket_new($stream, string $buffer): object {}
 
 /**
  * Add URL rewriter values
@@ -1083,7 +1158,7 @@ function stream_bucket_new($stream, $buffer) { }
  * </p>
  * @return bool true on success or false on failure.
  */
-function output_add_rewrite_var($name, $value) { }
+function output_add_rewrite_var(string $name, string $value): bool {}
 
 /**
  * Reset URL rewriter values
@@ -1114,7 +1189,7 @@ function output_add_rewrite_var($name, $value) { }
  * @link https://php.net/manual/en/function.output-reset-rewrite-vars.php
  * @return bool true on success or false on failure.
  */
-function output_reset_rewrite_vars() { }
+function output_reset_rewrite_vars(): bool {}
 
 /**
  * Returns directory path used for temporary files
@@ -1122,7 +1197,7 @@ function output_reset_rewrite_vars() { }
  * @return string the path of the temporary directory.
  * @since 5.2.1
  */
-function sys_get_temp_dir() { }
+function sys_get_temp_dir(): string {}
 
 /**
  * Get the contents of the realpath cache.
@@ -1133,7 +1208,8 @@ function sys_get_temp_dir() { }
  * the cache.
  * @since 5.3.2
  */
-function realpath_cache_get() { }
+#[Pure]
+function realpath_cache_get(): array {}
 
 /**
  * Get the amount of memory used by the realpath cache.
@@ -1141,22 +1217,23 @@ function realpath_cache_get() { }
  * @return int Returns how much memory realpath cache is using.
  * @since 5.3.2
  */
-function realpath_cache_size() { }
+#[Pure]
+function realpath_cache_size(): int {}
 
 /**
  * It returns the same result as (array) $object, with the
  * exception that it ignores overloaded array casts, such as used by
  * ArrayObject.
- * @param $obj
+ * @param object $object
  * @return array returns the mangled object properties
  * @since 7.4
  */
-function get_mangled_object_vars($obj){}
+function get_mangled_object_vars(object $object): array {}
 
 /**
  * Get the type or object name of a variable
  *
- * @param mixed $var The variable being type checked.
+ * @param mixed $value The variable being type checked.
  * @return string Possibles values for the returned string are:
  *  - "int"
  *  - "float"
@@ -1170,7 +1247,8 @@ function get_mangled_object_vars($obj){}
  *  - "resource (closed)" for closed resources
  * @since 8.0
  */
-function get_debug_type(mixed $var): string {}
+#[Pure]
+function get_debug_type(mixed $value): string {}
 
 /**
  * A more obvious and type-safe form of "(int) $resource"
@@ -1179,4 +1257,5 @@ function get_debug_type(mixed $var): string {}
  * @return int
  * @since 8.0
  */
+#[Pure]
 function get_resource_id($resource): int {}
